#include <stdio.h>
#include "./examples.h"

#undef __FUNC__
#define __FUNC__ "prec_setup"
int prec_setup(MPI_Comm comm,Mat A,PC the_pc)
{
  PCType pc_name = PCNONE;
  int mytid,ierr;

  MPI_Comm_rank(comm,&mytid);
  /* ---------------------------------- *
   * ---- here is the crucial part ---- *
   * ---------------------------------- */
  PetscPrintf(comm,"Setting up NONE pc \n");
  ierr = PCSetType(the_pc,pc_name); CHKERRQ(ierr);

  ierr = ParPreSetup(comm,A,the_pc); CHKERRQ(ierr);

  return 0;
}

